@@ -27,7 +27,7 @@ geom_autodensity <- function(mapping = NULL, data = NULL,
     position = position,
     show.legend = show.legend,
     inherit.aes = inherit.aes,
-    params = list(
+    params = list2(
       bw = bw,
       adjust = adjust,
       kernel = kernel,
@@ -66,7 +66,7 @@ StatAutodensity <- ggproto('StatAutodensity', StatDensity,
           density = count / nrow(data)
         )
       })
-      binned <- ved_rbind(!!!binned)
+      binned <- vec_rbind(!!!binned)
       binned$scaled <- binned$density / max(binned$density)
       binned$ndensity <- binned$density / max(binned$density)
       binned$count <- binned$density * nrow(data)
