@@ -1,8 +1,9 @@
 #' Draw an area defined by an upper and lower diagonal
 #'
 #' The `geom_diagonal_wide()` function draws a *thick* diagonal, that is, a
-#' polygon confined between a lower and upper [diagonal][geom_diagonal]. As with
-#' the diagonal functions in `ggforce`, the wide diagonal variant is horizontal.
+#' polygon confined between a lower and upper [diagonal][geom_diagonal]. This
+#' geom is bidirectional and the direction can be controlled with the
+#' `orientation` argument.
 #'
 #' @section Aesthetics:
 #' geom_diagonal_wide understand the following aesthetics
@@ -12,19 +13,22 @@
 #' - **y**
 #' - **group**
 #' - color
-#' - size
+#' - linewidth
 #' - linetype
 #' - alpha
 #' - lineend
 #'
 #' @inheritParams geom_shape
 #' @inheritParams ggplot2::stat_identity
+#' @inheritParams ggplot2::geom_line
 #'
 #' @param n The number of points to create for each of the bounding diagonals
 #'
 #' @param strength The proportion to move the control point along the x-axis
 #' towards the other end of the bezier curve
 #'
+#' @inheritSection ggplot2::geom_line Orientation
+#'
 #' @name geom_diagonal_wide
 #' @rdname geom_diagonal_wide
 #'
@@ -55,48 +59,57 @@ NULL
 #' @usage NULL
 #' @export
 StatDiagonalWide <- ggproto('StatDiagonalWide', Stat,
+  setup_params = function(data, params) {
+    params$flipped_aes <- has_flipped_aes(data, params, ambiguous = TRUE)
+    params
+  },
   setup_data = function(data, params) {
+    data$flipped_aes <- params$flipped_aes
     if (any(table(data$group) != 4)) {
-      stop('Each group must consist of 4 points')
+      cli::cli_abort('Each group must consist of 4 points')
     }
     data
   },
-  compute_panel = function(data, scales, strength = 0.5, n = 100) {
+  compute_panel = function(data, scales, strength = 0.5, n = 100, flipped_aes = FALSE) {
+    data <- flip_data(data, flipped_aes)
     data <- data[order(data$group, data$x, data$y), ]
-    lower <- data[c(TRUE, FALSE, TRUE, FALSE), ]
-    upper <- data[c(FALSE, TRUE, FALSE, TRUE), ]
+    lower <- data[rep_len(c(TRUE, FALSE, TRUE, FALSE), nrow(data)), ]
+    upper <- data[rep_len(c(FALSE, TRUE, FALSE, TRUE), nrow(data)), ]
     lower <- add_controls(lower, strength)
     upper <- add_controls(upper[rev(seq_len(nrow(upper))), ], strength)
     lower <- StatBezier$compute_panel(lower, scales, n)
     upper <- StatBezier$compute_panel(upper, scales, n)
-    diagonals <- rbind(lower, upper)
+    diagonals <- vec_rbind(lower, upper)
     diagonals$index <- NULL
-    diagonals[order(diagonals$group), ]
+    diagonals <- diagonals[order(diagonals$group), ]
+    flip_data(diagonals, flipped_aes)
   },
   required_aes = c('x', 'y', 'group'),
-  extra_params = c('na.rm', 'n', 'strength')
+  extra_params = c('na.rm', 'n', 'strength', 'orientation')
 )
 #' @rdname geom_diagonal_wide
 #' @export
 stat_diagonal_wide <- function(mapping = NULL, data = NULL, geom = 'shape',
                                position = 'identity', n = 100, strength = 0.5,
-                               na.rm = FALSE, show.legend = NA,
+                               na.rm = FALSE, orientation = NA, show.legend = NA,
                                inherit.aes = TRUE, ...) {
   layer(
     stat = StatDiagonalWide, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
-    params = list(na.rm = na.rm, n = n, strength = strength, ...)
+    params = list2(na.rm = na.rm, orientation = orientation, n = n,
+                  strength = strength, ...)
   )
 }
 #' @rdname geom_diagonal_wide
 #' @export
-geom_diagonal_wide <- function(mapping = NULL, data = NULL,
-                               stat = 'diagonal_wide', position = 'identity',
-                               n = 100, na.rm = FALSE, strength = 0.5,
+geom_diagonal_wide <- function(mapping = NULL, data = NULL, stat = 'diagonal_wide',
+                               position = 'identity', n = 100, na.rm = FALSE,
+                               orientation = NA, strength = 0.5,
                                show.legend = NA, inherit.aes = TRUE, ...) {
   layer(
     data = data, mapping = mapping, stat = stat, geom = GeomShape,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
-    params = list(na.rm = na.rm, n = n, strength = strength, ...)
+    params = list2(na.rm = na.rm, orientation = orientation, n = n,
+                  strength = strength, ...)
   )
 }
