@@ -75,6 +75,13 @@
 #'   geom_mark_ellipse(aes(fill = Species, label = Species),
 #'                     con.cap = 0) +
 #'   geom_point()
+#'
+#' # If you want to use the scaled colours for the labels or connectors you can
+#' # use the "inherit" keyword instead
+#' ggplot(iris, aes(Petal.Length, Petal.Width)) +
+#'   geom_mark_ellipse(aes(fill = Species, label = Species),
+#'                     label.fill = "inherit") +
+#'   geom_point()
 NULL
 
 #' @rdname ggforce-extensions
@@ -123,29 +130,42 @@ GeomMarkEllipse <- ggproto('GeomMarkEllipse', GeomMarkCircle,
       }
     }
 
+    gp <- gpar(
+      col = first_rows$colour,
+      fill = ggplot2::fill_alpha(first_rows$fill, first_rows$alpha),
+      lwd = (first_rows$linewidth %||% first_rows$size) * .pt,
+      lty = first_rows$linetype,
+      fontsize = (first_rows$size %||% 4.217518) * .pt
+    )
+
     ellipEncGrob(coords$x, coords$y,
       default.units = 'native',
       id = coords$group, expand = expand, radius = radius, n = n,
       tol = tol, label = label, ghosts = ghosts,
-      mark.gp = gpar(
-        col = first_rows$colour,
-        fill = alpha(first_rows$fill, first_rows$alpha),
-        lwd = (first_rows$linewidth %||% first_rows$size) * .pt,
-        lty = first_rows$linetype
-      ),
-      label.gp = gpar(
-        col = label.colour,
+      mark.gp = gp,
+      label.gp = inherit_gp(
+        col = label.colour[1],
         fill = label.fill,
-        fontface = label.fontface,
-        fontfamily = label.family,
-        fontsize = label.fontsize,
-        lineheight = label.lineheight
+        fontface = label.fontface[1],
+        fontfamily = label.family[1],
+        fontsize = label.fontsize[1],
+        lineheight = label.lineheight[1],
+        gp = gp
       ),
-      con.gp = gpar(
+      desc.gp = inherit_gp(
+        col = rep_len(label.colour, 2)[2],
+        fontface = rep_len(label.fontface, 2)[2],
+        fontfamily = rep_len(label.family, 2)[2],
+        fontsize = rep_len(label.fontsize, 2)[2],
+        lineheight = rep_len(label.lineheight, 2)[2],
+        gp = gp
+      ),
+      con.gp = inherit_gp(
         col = con.colour,
         fill = con.colour,
-        lwd = con.size * .pt,
-        lty = con.linetype
+        lwd = if (is.numeric(con.size)) con.size * .pt else con.size,
+        lty = con.linetype,
+        gp = gp
       ),
       label.margin = label.margin,
       label.width = label.width,
@@ -189,7 +209,7 @@ geom_mark_ellipse <- function(mapping = NULL, data = NULL, stat = 'identity',
     position = position,
     show.legend = show.legend,
     inherit.aes = inherit.aes,
-    params = list(
+    params = list2(
       na.rm = na.rm,
       expand = expand,
       radius = radius,
@@ -225,7 +245,7 @@ ellipEncGrob <- function(x = c(0, 0.5, 1, 0.5), y = c(0.5, 1, 0.5, 0), id = NULL
                          id.lengths = NULL, expand = 0, radius = 0, n = 100,
                          tol = 0.01, label = NULL, ghosts = NULL,
                          default.units = 'npc', name = NULL, mark.gp = gpar(),
-                         label.gp = gpar(), con.gp = gpar(),
+                         label.gp = gpar(), desc.gp = gpar(), con.gp = gpar(),
                          label.margin = margin(), label.width = NULL,
                          label.minwidth = unit(50, 'mm'), label.hjust = 0,
                          label.buffer = unit(10, 'mm'), con.type = 'elbow',
@@ -261,11 +281,14 @@ ellipEncGrob <- function(x = c(0, 0.5, 1, 0.5), y = c(0.5, 1, 0.5, 0), id = NULL
   )
   if (!is.null(label)) {
     label <- lapply(seq_len(nrow(label)), function(i) {
+      if (is.na(label$label[i] %||% NA) && is.na(label$description[i] %||% NA)) return(zeroGrob())
       grob <- labelboxGrob(label$label[i], 0, 0, label$description[i],
-        gp = label.gp, pad = label.margin, width = label.width,
+        gp = subset_gp(label.gp, i), desc.gp = subset_gp(desc.gp, i),
+        pad = label.margin, width = label.width,
         min.width = label.minwidth, hjust = label.hjust
       )
       if (con.border == 'all') {
+        con.gp <- subset_gp(con.gp, i)
         grob$children[[1]]$gp$col <- con.gp$col
         grob$children[[1]]$gp$lwd <- con.gp$lwd
         grob$children[[1]]$gp$lty <- con.gp$lty
